@@ -13,8 +13,7 @@ These physical tools are helpers around CFD-related problems.
 """
 
 
-from .solid_material import *
-from .thermodyn_properties import *
-from .wall_thermal_equilibrium import *
-from .yk_from_phi import *
-
+from arnica.phys.solid_material import *
+from arnica.phys.thermodyn_properties import *
+from arnica.phys.wall_thermal_equilibrium import *
+from arnica.phys.yk_from_phi import *
