@@ -24,13 +24,13 @@ Untested - to be deleted :
 
 """
 
-from .axishell import *
-from .cloud2cloud import *
-from .directed_projection import *
-from .nparray2xmf import *
-from .vector_actions import *
-from .showy import *
-from .sample_curve_from_cloud import *
-from .same_nob import *
+from arnica.utils.axishell import *
+from arnica.utils.cloud2cloud import *
+from arnica.utils.directed_projection import *
+from arnica.utils.nparray2xmf import *
+from arnica.utils.vector_actions import *
+from arnica.utils.showy import *
+from arnica.utils.sample_curve_from_cloud import *
+from arnica.utils.same_nob import *
 
-from .axipointcloud import *
+from arnica.utils.axipointcloud import *
