@@ -3,8 +3,7 @@ limited to point cloud (connectivity sucks, mark my word, really) """
 import warnings
 import h5py
 import numpy as np
-from .vector_actions import renormalize
-
+from arnica.utils.vector_actions import renormalize
 
 
 
