@@ -169,8 +169,13 @@ def dump_dico_1d_nparrays(filename, data_dict):
         n_columns = len(data_dict.keys())
         n_lines = data_dict[next(iter(data_dict.keys()))].shape[0]
         out_array = np.zeros((n_lines, n_columns))
-        for col, key in enumerate(data_dict, 0):
-            out_array[:, col] = data_dict[key][:]
+        try:
+            for col, key in enumerate(data_dict, 0):
+                out_array[:, col] = data_dict[key][:]
+        except ValueError as err:
+            msg_err = f"Shape error in key {key}\n"
+            msg_err += str(err)
+            raise ValueError(msg_err)
         np.savetxt(file_out, out_array, delimiter=' , ', header=header)
 
 def dump_dict2xmdf(filename, grid, data_dict):
